@@ -1,7 +1,7 @@
 "ghyp.data" <- function(object){
     test.ghyp(object, case = "ghyp")
     if(length(object@data) != 0){
-      if(object@dimension == 1){
+      if(is.univariate(object)){
         return(as.vector(object@data))      
       }else{
         return(object@data)
