@@ -7,6 +7,13 @@
   ## Only univariate 'ghyp' objects are allowed
   test.ghyp(object, case = "univariate")
 
+  if(is.gaussian(object)){
+    return(qnorm(p, mean = object@mu, sd = object@sigma))
+  }else if(is.symmetric.t(object)){
+     nu <- -2 * coef(object)$lambda
+     return(qt(p, df = nu) * sqrt((nu - 2) / nu) * object@sigma + object@mu)  
+  }
+
   p.raw  <- check.data(p, na.rm = FALSE, fit = FALSE, dim = 1)
 
   method <- match.arg(method)
@@ -21,60 +28,99 @@
     return(p.raw)
   }
   #<----   Use Newton's method to find the range of the quantiles ---->
-  internal.newton <- function(object, p, tol, rel.tol, abs.tol, subdivisions)
+
+  internal.bisection <- function(object, p, tol, rel.tol, abs.tol, subdivisions)
   {
-    newton.tol <- 1
     iter <- 0
-    x0 <- mean(object)
-    while(newton.tol > tol & iter < 100){
+    range.found <- FALSE
+    step.size <- sqrt(vcov(object))
+
+    if(!is.finite(step.size)){
+      step.size <- coef(object, type = "chi.psi")$sigma / 2
+    }
+
+    q.0 <- mean(object)
+    q.range <- c(q.0 - step.size, q.0 + step.size)
+
+    while(!range.found & iter < 100){
       iter <- iter + 1
-      F1 <- pghyp(q = x0, object, rel.tol = rel.tol, abs.tol = abs.tol,
-                  subdivisions = subdivisions) - p
-      x1 <- x0 - F1/dghyp(x0, object)
-      newton.tol <- abs((x1 - x0)/x0)
-      x0 <- x1
-##      cat("x0: ",x0, "  F1: ", F1, " newton.tol", newton.tol,"\n")
-      if(is.nan(newton.tol)){
-        stop("Unable to determine interval where the quantiles are in-between.\n",
-              "Perhaps the skewness is too large!") 
+      p.range <- pghyp(q = q.range, object, rel.tol = rel.tol, abs.tol = abs.tol,
+                       subdivisions = subdivisions) - p  
+      
+      if(any(is.na(p.range))){
+        warning("Unable to determine interval where the quantiles are in-between.\n",
+                "Perhaps the skewness is too large!") 
+        return(NA)              
+      }
+
+      lower <- p.range[1]
+      upper <- p.range[2]
+       
+##      cat("lower: ", lower,";  upper : ", upper, "\n")
+      if(upper < 0 & lower < 0){
+        q.range[1] <- q.range[2]
+        q.range[2] <- q.range[2] + step.size
+        next
+      }
+      if(upper > 0 & lower > 0){
+        q.range[2] <- q.range[1]
+        q.range[1] <- q.range[1] - step.size
+        next
+      }
+      if(upper > 0 & lower < 0){
+        range.found <- TRUE
       }
     }
-    return(x0)
+    if(iter >= 100){
+      warning("Unable to determine interval where the quantiles are in-between.\n",
+              "Perhaps the skewness is too large!") 
+    }
+    
+    q.root <- q.default(p, pdf = "internal.dghyp", pdf.args = coef(object, type = "chi.psi"), 
+                        interval = q.range, tol = root.tol,
+                        p.lower = -Inf, rel.tol = rel.tol, abs.tol = abs.tol,
+                        subdivisions = subdivisions)
+    return(q.root)
   }
+ 
+  
   #<---------------- end of Newton iteration  ---------------------->
 
   if(length(p) == 1){
     ## If a single quantile is requested use the newton method anyway
-    value <- internal.newton(object, p, root.tol, rel.tol, abs.tol, subdivisions)
+    value <- internal.bisection(object, p, root.tol, rel.tol, abs.tol, subdivisions)
     p.raw[is.finite(p.raw)] <- value
     return(p.raw)
   }else if(length(p) == 2){
     ## If two quantiles are requested use the newton method anyway
-    value1 <- internal.newton(object, p[1], root.tol, rel.tol, abs.tol, subdivisions)
-    value2 <- internal.newton(object, p[2], root.tol, rel.tol, abs.tol, subdivisions)
+    value1 <- internal.bisection(object, p[1], root.tol, rel.tol, abs.tol, subdivisions)
+    value2 <- internal.bisection(object, p[2], root.tol, rel.tol, abs.tol, subdivisions)
     p.raw[is.finite(p.raw)] <- c(value1, value2)
     return(p.raw)
   }else{
     ## If more than two quantiles are requested use the newton method 
     ## to find the range where the quantiles can be found.
-    q.min <- internal.newton(object, min(p), root.tol, rel.tol, abs.tol, subdivisions)
-    q.max <- internal.newton(object, max(p), root.tol, rel.tol, abs.tol, subdivisions)
+    q.min <- internal.bisection(object, min(p), root.tol, rel.tol, abs.tol, subdivisions)
+    q.max <- internal.bisection(object, max(p), root.tol, rel.tol, abs.tol, subdivisions)
 
     interval <- c(q.min, q.max)
+    
+    if(any(is.na(interval))){ # -> Failed to determine bounds for the quantiles
+      p.raw[is.finite(p.raw)] <- NA
+      return(p.raw)
+    }
 
     ## Extend the interval by 10 percent so that 'uniroot' does not crash
     interval <- c(interval[1] - 0.01 * diff(range(interval)),
                   interval[2] + 0.01 * diff(range(interval)))
     #<---------------------  Integration method  ------------------------->
     if(method == "integration"){
-      pdf.args <- list(lambda = object@lambda, chi = object@chi, psi = object@psi,
-                       mu = object@mu, sigma = object@sigma, gamma = object@gamma)
+      pdf.args <- coef(object, type = "chi.psi")
       p <- matrix(p, ncol = 1)
-      q.val <- apply(p, MARGIN = 1, FUN = q.default, pdf = "internal.dghyp",
+      value <- apply(p, MARGIN = 1, FUN = q.default, pdf = "internal.dghyp",
                      pdf.args = pdf.args, interval = interval, tol = root.tol,
                      p.lower = -Inf, rel.tol = rel.tol, abs.tol = abs.tol,
                      subdivisions = subdivisions)
-      value <- sapply(q.val, FUN = function(x)x$root)
     }else{
     #<-----------------------  Splines method  --------------------------->
       interval.seq <- seq(min(interval), max(interval), length = spline.points)
